@@ -4,7 +4,7 @@ require Exporter;
 @EXPORT_OK = qw/to_singular/;
 use warnings;
 use strict;
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Irregular plurals.
 
@@ -115,6 +115,10 @@ sub to_singular
 		# report's, etc.
 		;
 	    }
+	    elsif (length ($word) <= 2) {
+		# is, as, letter s, etc.
+		;
+	    }
 	    elsif ($word =~ /ss$/) {
 		# useless, etc.
 		;
